@@ -38,7 +38,7 @@ describe 'manila::backend::dellemc_unity' do
 
     it 'configures dell emc unity share driver' do
       is_expected.to contain_manila_config("dellemc_unity/share_driver").with_value(
-        'manila.share.drivers.emc.driver.EMCShareDriver')
+        'manila.share.drivers.dell_emc.driver.EMCShareDriver')
       params_hash.each_pair do |config,value|
         is_expected.to contain_manila_config("dellemc_unity/#{config}").with_value( value )
       end
@@ -49,27 +49,39 @@ describe 'manila::backend::dellemc_unity' do
     end
   end
 
+  shared_examples 'manila::backend::dellemc_unity' do
+    context 'with default parameters' do
+      before do
+        params = {}
+      end
 
-  context 'with default parameters' do
-    before do
-      params = {}
+      it_configures 'dell emc unity share driver'
     end
 
-    it_configures 'dell emc unity share driver'
-  end
-
-  context 'with provided parameters' do
-    it_configures 'dell emc unity share driver'
-  end
-
-  context 'with share server config' do
-    before do
-      params.merge!({
-        :emc_nas_password => true,
-      })
+    context 'with provided parameters' do
+      it_configures 'dell emc unity share driver'
     end
 
-    it { is_expected.to raise_error(Puppet::Error, /true is not a string.  It looks to be a TrueClass/) }
+    context 'with share server config' do
+      before do
+        params.merge!({
+          :emc_nas_password => true,
+        })
+      end
+
+     it { is_expected.to raise_error(Puppet::Error) }
+    end
   end
 
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      it_behaves_like 'manila::backend::dellemc_unity'
+    end
+  end
 end
